#
# spec file for package libchewing
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%define with_utils 1
%if %{with_utils}
%define utilver 0.4.0+git20150602.81299e5
%endif

Name:           libchewing
%define soname	3
Version:        0.5.1+git20200627.452f622
Release:        2.2
Summary:        Intelligent Phonetic Input Method Library for Traditional Chinese
License:        LGPL-2.1-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/chewing
Source:         %{name}-%{version}.tar.xz
Source1:        chewing-utils-%{utilver}.tar.gz
#PATCH-FIX-UPSTREAM yuyichao@gmail.com fix a lot of errors in the code
Source2:        chewing-utils-abuild.patch
#PATCH-FIX-UPSTREAM marguerite@opensuse.org remove rpath from simple-select
Patch0:         libchewing-0.4.0-simple-select-rpath.patch
Source99:       baselibs.conf
BuildRequires:  autoconf >= 2.67
%if %{with_utils}
BuildRequires:  gtk2-devel
%endif
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
BuildRequires:  sqlite3-devel
Requires(post): info
Requires(postun):info

%description
Intelligent phonetic input method library for traditional Chinese.

%package devel
Summary:        Development package for chewing
Group:          Development/Libraries/C and C++
Requires:       %{name}%{soname} = %{version}
Requires:       python-chewing = %{version}

%description devel
Development package for chewing (An Intelligent phonetic input method library for traditional Chinese)

%package -n %{name}%{soname}
Summary:        Chewing libraries
Group:          System/Libraries
Requires:       chewing-data
Recommends:     chewing-utils = %{version}

%description -n %{name}%{soname}
This package contains libraries for Chewing, an intelligent phonetic
input method library for traditional Chinese.

%package -n chewing-data
Summary:        Chewing Data for %{name}
Group:          System/I18n/Chinese

%description -n chewing-data
This package contains data files for chewing, an intelligent phonetic
input method library for traditional Chinese.

%package -n chewing-utils
Summary:        Hash editor for %{name}
Group:          System/I18n/Chinese

%description -n chewing-utils
This package contains a hash editor for chewing, an intelligent phonetic
input method library for tranditional Chinese.

It's used to add, modify and remove entries in the chewing user database
(usually located at ~/.chewing/uhash.dat).

%package -n python-chewing
Summary:        Python bindings for %{name}
Group:          Development/Libraries/Python

%description -n python-chewing
This package contains python bindings for chewing, an intelligent phonetic
input method library for traditional Chinese.

Only input method framework written in python (like very old versions of ibus)
or developers will need it.

%prep
%autosetup -p1

%build
# build libchewing main
./autogen.sh
NCURSESW6_CFLAGS=`ncursesw6-config --cflags`
NCURSESW6_LIBS=`ncursesw6-config --libs`
CFLAGS="$NCURSESW6_CFLAGS %{optflags} -fno-strict-aliasing" \
LIBS="$NCURSES_LIBS" \
%configure --disable-static --with-pic --with-ncurses

make %{?_smp_mflags}

# build contrib
pushd contrib
make -f Makefile %{?_smp_mflags}
popd

# build utils
cp -r %{SOURCE1} ./
tar -xf chewing-utils-%{utilver}.tar.gz
rm -rf chewing-utils-%{utilver}.tar.gz
pushd chewing-utils-%{utilver}/hash-editor
pushd ..
patch -p1 < %{SOURCE2}
popd
make %{?_smp_mflags}
popd

%install
# install main
make DESTDIR=%{buildroot} install %{?_smp_mflags}

# remove .la file
find %{buildroot}%{_libdir} -name "*.la" -delete

# install simple-select
mkdir -p %{buildroot}%{_bindir}
cp -r contrib/simple-select %{buildroot}%{_bindir}

# install python bindings
mkdir -p %{buildroot}%{python_sitearch}/chewing/
cp -r contrib/python/chewing.py %{buildroot}%{python_sitearch}/chewing/
pushd %{buildroot}%{python_sitearch}/chewing/
python3 -m py_compile *.py
popd

# install chewing-utils
mkdir -p %{buildroot}%{_docdir}/chewing-utils
pushd chewing-utils-%{utilver}
cp -r AUTHORS %{buildroot}%{_docdir}/chewing-utils/
cp -r COPYING %{buildroot}%{_docdir}/chewing-utils/
cp -r hash-editor/ChangeLog.old %{buildroot}%{_docdir}/chewing-utils/ChangeLog
cp -r hash-editor/src/che %{buildroot}%{_bindir}
cp -r hash-editor/src/zhuindict_compile %{buildroot}%{_bindir}
popd

%post -n %{name}%{soname}
/sbin/ldconfig
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun -n %{name}%{soname} -p /sbin/ldconfig

%preun -n %{name}%{soname}
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files -n %{name}%{soname}
%license COPYING
%doc AUTHORS NEWS README.md TODO
%{_libdir}/libchewing.so.3
%{_libdir}/libchewing.so.3.3.1

%files -n chewing-data
%{_datadir}/%{name}/

%files -n python-chewing
%{python_sitearch}/chewing

%files -n chewing-utils
%{_bindir}/che
%{_bindir}/simple-select
%{_bindir}/zhuindict_compile
%doc %{_docdir}/chewing-utils

%files devel
%{_includedir}/chewing/
%{_libdir}/libchewing.so
%{_libdir}/pkgconfig/chewing.pc
%{_infodir}/*.gz

%changelog
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Wed Sep 29 2021 mcepl@suse.com
- Update to version 0.5.1+git20200627.452f622:
  * chewing.py supports platforms with 64bit pointer
  * Change ︰ to ：
  * Don't run tests in parallel
  * Try Ubuntu 16.04 Xenial
  * autotools: Build with -fPIC like the CMake-based one does
  * Show compilation commands if the build system is autotools
  * Tolerate unused const warnings
  * Fix LSan
  * Use internal-sqlite instead of static-sqlite, following 570ab6be
* Fri Sep 24 2021 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on python-devel, and the conflicting
  old py_* macros.
- Remove references to "Python 2", the module supports Python 3.
- Mark COPYING as license.
* Thu Aug 22 2019 Jan Engelhardt <jengelh@inai.de>
- Remove pointless ldconfig call from chewing-utils subpackage.
- Specfile update: remove implicit BuildRoot and defattrs.
- Properly fulfill SLPP requirement that only the library file
  is in the library subpackage.
* Fri Nov 24 2017 opensuse-packaging@opensuse.org
- Update to version 0.4.0+git20171114.3df07c9:
  * CMakeLists.txt: Add stress
  * sort data/tsi.sr
  * Add Carpalx keyboard layout support
  * Fix warning in GCC
  * Let CHEWING_DATA_PREFIX and TEST_DATA_DIR be absolute
  * Fix wrong CHEWING_DATADIR definition in CMake build
  * Fix jk_selection
  * an API to convert phone to bopomofo
  * Test chewing_phone_to_bopomofo with invalid phone
  * Implement has_userphrase with chewing_userphrase_lookup
  * libchewing.texi: Fix format tweaks
  * Adjust behavior of chewing_phone_to_bopomofo
  * Fix array index out of bound error in stress.c
  * Make stress.c less verbose
  * Prefer https for web links
  * stress.c: Don't force set data path
  * Fix #235: Unable to input some Bopomofos with ET26 layout
  * prevent memory leak in error case of GetDefaultUserPhrasePath
  * stress: clean_userphrase before each test
  * stress: clean up temp ~userphrase after test
  * stress: fix -extra argument parsing
  * refactoring key tables in chewing test
  * simplify simulate.c
  * testchewing: support read input from file
  * stress: support read input from file
  * Fix PinYinData keySeq buffer overflow in PinYinInput()
  * Fix trying to allocate buffer of negative size
  * Fix access violation due to negative cursor position
  * stress.c: more verbose output
  * Fix heap-buffer-overflow when read wordSeq
  * Use strncmp to avoid buffer overflow
  * tree: avoid undefined allocation of 0 bytes (CERT MEM04-C; CWE-131)
  * pinyin: avoid null-pointer dereference
  * chewingutil: fix dead assignment
  * Revert "libchewing.texi: Add chewing_bopomofo_String"
  * Fix memory leak in Discard2
  * Fix memory leak in UserUpdatePhrase().
  * code clean up, use new DestroyUserPhraseData()
  * userphrase-hash: avoid double free in TerminateUserphrase
  * test-userphrase: add test_userphrase_double_free
  * hash: fix hash item offset calculating in uhash.dat
  * hash: fix memory leak in HashFileOffsetWithUserPhrase
  * hash: fix memory access alignment
  * Fix ChoiceEndChoice expression always true
  * hash: follow consistent coding style
  * Update jvc-convert of KB layout Hsu
  * Auto learn phrases only after committing
  * Implement chewing_set_autoLearn() and chewing_get_autoLearn()
  * Fix indent in test/stress.c
  * Fix build with internal sqlite3
  * Fix: chewing_handle_Space() cannot input space when buffer is empty
  * hash: remove goto statement
  * Remove API changes/compatibility report link
  * hash: follow consistent coding style
* Tue Sep  1 2015 i@marguerite.su
- move %%install_info_delete to %%preun
* Mon Aug 24 2015 i@marguerite.su
- Update to version 0.4.0+git20150820.285b47d:
  + fix resource leak
  + Add notification_email
  + Update build_command_prepend
  + Do not write last element of phone_array
  + Prevent fclose null file handler
  + Check return value for ftell
  + Check return value of UserGetPhraseFirst before use
  + testhelper.c: clean_userphase() ignore ENOENT
  + init_database.c: Fix strtoul error checking
  + init_database: make integer comparison 64-bit safe
  + Fix Coverity error "Buffer not null terminated"
  + Fix Coverity error "Copy into fixed size buffer"
  + Fix Coverity error "Explicit null dereferenced"
  + init_database.c: Resolve queue-full exception
  + gen_keystroke.c: Use static APIs
  + genkeystroke.c: Fix buffer usage
  + Disable selection keys out of the reasonable range
  + dump_database: utilize plat_mmap for file operations
  + Fix ChewingKillChar which is disabling OpenSymbolChoice
  + Use chewing_delete to delete ChewingContext
  + Detect attribute existence by hasattr, not __dict__
* Mon Jun  9 2014 i@marguerite.su
- update version 0.4.0
  * see https://github.com/chewing/libchewing/releases
- add patch: libchewing-0.4.0-simple-select-rpath.patch
- add patch: chewing-utils-abuild.patch
* Fri Aug  2 2013 i@marguerite.su
- update version 0.3.5
  * Improve CMake rules
  - Visual Studio build included
  * Dictionary improvements
  - Remove duplicated phrases, fix Bopomofo representation
  - tool tweaks
  * travis-ci support (https://travis-ci.org/chewing/libchewing)
  * drone.io support (https://drone.io/github.com/chewing/libchewing)
  * coveralls.io support (https://coveralls.io/r/chewing/libchewing)
  * editorconfig support (http://editorconfig.org/)
  * Add new chewing_set_logger API
  * Prevent unaligned memory access
  * Reduce maxChiSymbolLen to 39 to avoid overflow
  * Do not store user phrase when its length is 1
  * Check chiSymbolBufLen in chewing_handle_Numlock()
  * Set isSymbol to 0 in SetChoiceInfo
  * Fix 'j', 'k' in select mode cannot handle symbol selecting
  * Do not call GetCharNext() when GetCharFirst() fails
  * Successful stories:
    FreeArray utilizes libchewing for selecting phrases of Array
    input method
* Sat Apr 27 2013 i@marguerite.su
- proper baselibs.conf and post(un) for %%lname.
* Fri Apr 26 2013 i@marguerite.su
- revert unnessary renaming chewing-devel back to libchewing-devel.
* Wed Apr 24 2013 i@marguerite.su
- retrack upstream source. previous source is from unknown origin.
  * it couldn't be found at the link in specfile.
  * it didn't have the same content and build result
    as upstream source.
  * it missed entire python and data sub directories,
    so almost useless.
- remove ambiguous libchewing package. fix bnc#808338
  * libchewing is always taken as an old version by users.
  * libchewing contained the runtime libraries but it was
    not required by libchewing3. important orphan package.
    so ibus-chewing and fcitx-chewing can't work.
- enable ncurses wide-char and thread-safe (w6)
- enable python.
- new sub-packages: chewing-data python-chewing chewing-utils
* Tue Apr 23 2013 coolo@suse.com
- fix baselibs.conf - there is no libchewing-32bit
* Thu Jan 24 2013 jengelh@inai.de
- Parallel build with %%_smp_mflags
- Remove redundant %%clean, authors sections
- Avoid requires on library, the other way is preferred
  (library requires data package)
* Thu Jan 17 2013 swyear@gmail.com
- Split libchewing.so.* into subpackage libchewing3
* Wed Jan 16 2013 swyear@gmail.com
- Update to libchewing 0.3.4
- Remove libchewing-gcc-fix.diff (upstream rewrite this part)
- Improve the description of libchewing API
    Simplified examples to illustrate the usage are added
- Revise libchewing API. Check the documentation for details
- Support THL (Taiwan Huayu Luomapinyin) and MPS2 Pinyin keyboard layout
- Reimplementation of unit test framework. No external 'check' package is required
- Fix several phrase errors
    Add exceptional phrase as well
- Improved developer and user guide
- Introduce CMake based build system, which is convenient to MS-Windows based environments.
- Add --enable-gcov to enable gcov coverage
- Fix possible strncat() overflow
- Consistent checks for bopomofo sequence internally
- Handle incomplete bopomofo with space key properly
- Internal structure refactoring
- Read hash path from CHEWING_PATH environment variable
- Make libchewing thread-safe
- Fix IM crash by changing default candidate per page to 10
- Fix the detection of ncursesw
- Fix the usage of autotools
- Update and tune symbols
- Fix valgrind warning
- Fix several compilation warnings
- Fix GCC visibility availability for Darwin specific PIC code
- Fix hash table initialization and its memory leakage
- Support building with mingw32 toolchain
- Fix GNU Hurd build
- Fix Microsoft VC build
- Fix Windows 64-bit build
- Fix mingw32/64 + WINE build
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit buildrequire to avoid implicit dependency from prjconf
* Tue Jun 14 2011 swyear@gmail.com
- Update to libchewing 0.3.3:
  Fix setfault, improved python-binding, build fixes, etc;
  see http://chewing.csie.net/news.html for details
* Thu Mar  4 2010 coolo@novell.com
- fix buffer overflow
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Sep 21 2009 tiwai@suse.de
- fix to apply the previous patch properly
* Fri Sep 11 2009 ro@suse.de
- fix missing call to fclose in sort_word.c (bnc#535452)
* Wed Jun 17 2009 tiwai@suse.de
- updated to version 0.3.2, including previous fix patches,
  fix memory leaks, doxygen updates, etc.
  See ChangeLog for details.
- build with -fno-strict-aliasing to avoid type punning problems
  in src/hash.c
* Wed Jan 28 2009 crrodriguez@suse.de
- remove "la" files with empty dependency_libs
- remove static libraries
* Tue Dec  4 2007 mfabian@suse.de
- fix build with glibc 2.7.
- fix some rpmlint warnings.
* Mon Apr  9 2007 ro@suse.de
- fix build with updated check package
* Tue Mar 27 2007 sbrabec@suse.cz
- Require check-devel.
* Tue Oct 31 2006 meissner@suse.de
- use RPM_OPT_FLAGS correctly.
* Thu Jul 13 2006 mfabian@suse.de
- update to 0.3.0:
  + This is a new development branch differing a lot from
  + 0.2.x series, and breaks API/ABI for new features.
  + UTF-8 based language engine core for common Unicode
  + environment.
  + Porting layer for POSIX/Unix-like and Win32 to reduce the
  + redundant porting process.
  + New API design for better consistency.
  + Merge the efforts from libchewing-data subproject, which
  + means various phrases have been reviewed and corrected.
  + Zuin fixes and symbol improvements.
  + Support key 'j' / 'k' for paging in selection mode.
  + Fix some internal memory management bugs and leaks.
  + Improved internal test suite.
  + New binary-form of user hash data to speed up loading and
  + solve hash data corruption.
  + Better calculating of internal tree and phone constants.
  + Revised tsi.src for richer phrases and avoiding crashes.
  + Merge phone and phrase from CNS11643.
  + Reduce the amount for the expose for internal symbols.
  + Improved Han-Yu PinYin to use table-lookup implementation.
  + Experimental frequency-evaluation. (re-compute chewing
  + lifetime)
  + Implement the choice mechanism for pair symbols.
  + Improved Tab handling to allow the switching over different
  + frequency orders of candidated phrases.
  + New auxiliary module for simpler API uses.
  + Experimental memory-mapping based binary data handling to
  + speed up data loading.
- add "check" to BuildRequires.
- adapt bugzilla-155270-libchewing-init-chewing-correctly.patch
* Tue May 23 2006 zsu@suse.de
- bugzilla #155270,#177882 new patch for #155270 to avoid #177882.
  Clearing the whole ChewingData structure will clear config data
  as well, which causes another crash in libchewing (#177882).
  So we need keep ChewingData.Config member while clearing others.
* Tue May  9 2006 zsu@suse.de
- bugzilla #155270: Fix scim crash issue when switching from Chewing
  to other input method.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 mfabian@suse.de
- fix libtool problem in configure.ac to make the package build
  again.
* Tue Aug  9 2005 mfabian@suse.de
- update to 0.2.7.
* Mon Feb 28 2005 mfabian@suse.de
- update to 0.2.6.
* Thu Feb 17 2005 mfabian@suse.de
- libchewing did overwrite the return value of getenv("HOME")
  and added ".chewing". This is bad because it changed the value
  of HOME in the environment. If the value of HOME is wrong,
  external graphical programs like the Anthy dictionary interface
  "kasumi" cannot be started anymore from the scim-panel because
  they cannot find ~/.Xauthority and therefore cannot open a
  window.
* Tue Jan 25 2005 mfabian@suse.de
- update to 0.2.5.
* Tue Dec 21 2004 mfabian@suse.de
- new package: libchewing, version 0.2.4.
